pub struct FlexibleButtons(/* private fields */);Implementations
Sourceimpl FlexibleButtons
impl FlexibleButtons
pub const PLAY: FlexibleButtons
pub const PAUSE: FlexibleButtons
pub const STOP: FlexibleButtons
Sourceimpl FlexibleButtons
impl FlexibleButtons
Sourcepub const fn empty() -> FlexibleButtons
pub const fn empty() -> FlexibleButtons
Get a flags value with all bits unset.
Sourcepub const fn all() -> FlexibleButtons
pub const fn all() -> FlexibleButtons
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<FlexibleButtons>
pub const fn from_bits(bits: u32) -> Option<FlexibleButtons>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> FlexibleButtons
pub const fn from_bits_truncate(bits: u32) -> FlexibleButtons
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> FlexibleButtons
pub const fn from_bits_retain(bits: u32) -> FlexibleButtons
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FlexibleButtons>
pub fn from_name(name: &str) -> Option<FlexibleButtons>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FlexibleButtons) -> bool
pub const fn intersects(&self, other: FlexibleButtons) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: FlexibleButtons) -> bool
pub const fn contains(&self, other: FlexibleButtons) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: FlexibleButtons)
pub fn insert(&mut self, other: FlexibleButtons)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: FlexibleButtons)
pub fn remove(&mut self, other: FlexibleButtons)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FlexibleButtons)
pub fn toggle(&mut self, other: FlexibleButtons)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: FlexibleButtons, value: bool)
pub fn set(&mut self, other: FlexibleButtons, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: FlexibleButtons) -> FlexibleButtons
pub const fn intersection(self, other: FlexibleButtons) -> FlexibleButtons
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: FlexibleButtons) -> FlexibleButtons
pub const fn union(self, other: FlexibleButtons) -> FlexibleButtons
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: FlexibleButtons) -> FlexibleButtons
pub const fn difference(self, other: FlexibleButtons) -> FlexibleButtons
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: FlexibleButtons,
) -> FlexibleButtons
pub const fn symmetric_difference( self, other: FlexibleButtons, ) -> FlexibleButtons
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> FlexibleButtons
pub const fn complement(self) -> FlexibleButtons
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl FlexibleButtons
impl FlexibleButtons
Sourcepub const fn iter(&self) -> Iter<FlexibleButtons> ⓘ
pub const fn iter(&self) -> Iter<FlexibleButtons> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FlexibleButtons> ⓘ
pub const fn iter_names(&self) -> IterNames<FlexibleButtons> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl FlexibleButtons
impl FlexibleButtons
pub fn from_bits_allow_unknown(bits: u32) -> FlexibleButtons
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32