pub struct StrictButtons(/* private fields */);Implementations
Sourceimpl StrictButtons
impl StrictButtons
pub const PLAY: StrictButtons
pub const PAUSE: StrictButtons
pub const STOP: StrictButtons
Sourceimpl StrictButtons
impl StrictButtons
Sourcepub const fn empty() -> StrictButtons
pub const fn empty() -> StrictButtons
Get a flags value with all bits unset.
Sourcepub const fn all() -> StrictButtons
pub const fn all() -> StrictButtons
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<StrictButtons>
pub const fn from_bits(bits: u32) -> Option<StrictButtons>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> StrictButtons
pub const fn from_bits_truncate(bits: u32) -> StrictButtons
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> StrictButtons
pub const fn from_bits_retain(bits: u32) -> StrictButtons
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<StrictButtons>
pub fn from_name(name: &str) -> Option<StrictButtons>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: StrictButtons) -> bool
pub const fn intersects(&self, other: StrictButtons) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: StrictButtons) -> bool
pub const fn contains(&self, other: StrictButtons) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: StrictButtons)
pub fn insert(&mut self, other: StrictButtons)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: StrictButtons)
pub fn remove(&mut self, other: StrictButtons)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: StrictButtons)
pub fn toggle(&mut self, other: StrictButtons)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: StrictButtons, value: bool)
pub fn set(&mut self, other: StrictButtons, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: StrictButtons) -> StrictButtons
pub const fn intersection(self, other: StrictButtons) -> StrictButtons
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: StrictButtons) -> StrictButtons
pub const fn union(self, other: StrictButtons) -> StrictButtons
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: StrictButtons) -> StrictButtons
pub const fn difference(self, other: StrictButtons) -> StrictButtons
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: StrictButtons) -> StrictButtons
pub const fn symmetric_difference(self, other: StrictButtons) -> StrictButtons
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> StrictButtons
pub const fn complement(self) -> StrictButtons
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl StrictButtons
impl StrictButtons
Sourcepub const fn iter(&self) -> Iter<StrictButtons> ⓘ
pub const fn iter(&self) -> Iter<StrictButtons> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StrictButtons> ⓘ
pub const fn iter_names(&self) -> IterNames<StrictButtons> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.